@@ -4,8 +4,9 @@
 #'
 #' @author Greg Pilgrim \email{gpilgrim2670@@gmail.com}
 #'
-#' @import stringr
-#' @import purrr
+#' @importFrom stringr str_detect
+#' @importFrom stringr str_split_fixed
+#' @importFrom purrr map_dbl
 #'
 #' @param x A character vector of time(s) in swimming format (eg 1:35.93) to be converted to seconds (95.93)
 #' @return returns the value of the string \code{x} which represents a time in swimming format (mm:ss.hh) and converts it to seconds
@@ -14,6 +15,7 @@
 #' sec_format("16:45.19")
 #' sec_format("25.43")
 #' sec_format(c("1:35.93", "16:45.19", "25.43"))
+#' sec_format(c("1:35.93", "16:45.19", NA, "25.43"))
 #'
 #' @seealso \code{\link{mmss_format}} \code{sec_format} is the reverse of \code{mmss_format}
 #'
@@ -21,7 +23,11 @@
 
 
 sec_format <- function(x) {
-  if(sum(map_lgl(x, is.character)) != length(x)) stop("Enter swim formatted time as character string eg '1:35.97'")
+  # if (any(is.na(x)) == TRUE) { return(x)
+  #   } else {
+  # x <- na.omit(x)
+  # if(sum(map_lgl(x, is.character)) != length(x)) stop("Enter swim formatted time as character string eg '1:35.97'")
   x <- map_dbl(x, sec_format_helper)
   return(x)
+    # }
 }
